AcpMethodKey class final

A unique method-registry key.

Constructors

AcpMethodKey({required String name, required AcpMethodDirection direction, required AcpMethodKind kind})
Creates a method key.
const

Properties

direction AcpMethodDirection
The direction in which the method travels.
final
hashCode int
The hash code for this object.
no setteroverride
kind AcpMethodKind
Whether the message expects a response.
final
name String
The exact JSON-RPC method string.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override