AcpHttpAdapter class abstract interface

Platform boundary used by the experimental HTTP/SSE client.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() Future<void>
Releases adapter-owned resources. Calls are idempotent.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
send(AcpHttpRequest request) Future<AcpHttpResponse>
Sends request and resolves when response headers are available.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited