AcpHttpRequest class final

One platform-neutral streaming HTTP request.

Constructors

AcpHttpRequest({required Uri uri, required String method, required CancellationToken cancellationToken, AcpHttpHeaders headers = const AcpHttpHeaders(), List<int>? body, AcpHttpCookiePolicy cookiePolicy = AcpHttpCookiePolicy.include})
Creates a request.
const

Properties

body List<int>?
Optional request body bytes.
final
cancellationToken CancellationToken
Cancels the request and response body.
final
cookiePolicy AcpHttpCookiePolicy
Cookie behavior requested from the platform.
final
hashCode int
The hash code for this object.
no setterinherited
headers AcpHttpHeaders
Immutable request headers.
final
method String
Uppercase HTTP method.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
uri Uri
Request URI.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited