AcpSseLimitException class final

Thrown when a complete SSE event exceeds its configured bound.

Implemented types

Constructors

AcpSseLimitException({required int length, required int maximum})
Creates a limit exception.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
length int
Observed event bytes.
final
maximum int
Configured maximum.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited