AcpProtocolRouterConnectOptions class final
Startup options for a routed agent connection.
Constructors
- AcpProtocolRouterConnectOptions({bool deferConnectHandlers = false})
-
Creates router startup options.
const
Properties
- deferConnectHandlers → bool
-
Whether selected app connect handlers await manual start.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited