closed property
Future<void>
get
closed
Completes when routing or the selected application connection ends.
Implementation
Future<void> get closed => _closed.future;
Completes when routing or the selected application connection ends.
Future<void> get closed => _closed.future;