AcpHttpServerAdapter class abstract interface

Platform boundary for hosting AcpHttpServer.

Properties

hashCode int
The hash code for this object.
no setterinherited
isSupported bool
Whether this platform can bind a native HTTP listener.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serve(AcpHttpServer server, {String host = '127.0.0.1', int port = 0, String path = '/acp', bool shared = false, AcpWebSocketServer? webSocketServer}) Future<AcpHttpServerBinding>
Binds server at host, port, and path.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited