AcpHttpServerBinding class abstract interface

A running platform HTTP listener serving experimental ACP transports.

Properties

endpoint Uri
Loopback or explicitly configured endpoint.
no setter
hashCode int
The hash code for this object.
no setterinherited
isClosed bool
Whether close has completed.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() Future<void>
Stops accepting traffic and releases transport-owned resources.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited