AcpPreparedWebSocketUpgrade class final

A connection reserved before an HTTP adapter accepts its upgrade.

Properties

connectionId String
Opaque routing identifier to attach to the 101 response.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

accept(AcpWebSocketChannel channel) AcpWebSocketServerSession
Attaches the accepted channel and starts protocol initialization.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reject() Future<void>
Releases a reserved connection after the HTTP upgrade is rejected.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited