nextConnectionId method
Generates an ID not used by an active or pending state.
Implementation
String nextConnectionId() => _generateConnectionId(reserve: false);
Generates an ID not used by an active or pending state.
String nextConnectionId() => _generateConnectionId(reserve: false);