AcpSessionRoute class final

A session-specific response/event stream.

Inheritance

Constructors

AcpSessionRoute(String sessionId)
Creates a session route.
const

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionId String
The exact session identifier.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override