AcpWebSocketUpgradeRejected class final

Safe rejection from an ACP WebSocket preflight.

Implemented types

Constructors

AcpWebSocketUpgradeRejected([String message = 'WebSocket upgrade rejected'])
Creates a rejection with a non-sensitive message.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
message String
Redacted explanation suitable for a local diagnostic.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited