AcpV2ApplicationOptions class final

Application behavior switches for draft ACP v2.

Constructors

AcpV2ApplicationOptions({bool allowUnstableMethods = false, bool requireInitialization = true, JsonRpcConnectionOptions jsonRpcOptions = const JsonRpcConnectionOptions(allowBatches: true)})
Creates immutable options.
const

Properties

allowUnstableMethods bool
Whether unstable-overlay descriptors may be registered and sent.
final
hashCode int
The hash code for this object.
no setterinherited
jsonRpcOptions JsonRpcConnectionOptions
JSON-RPC concurrency, queue, batch, and diagnostic configuration.
final
requireInitialization bool
Whether normal traffic requires successful initialization.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({bool? allowUnstableMethods, bool? requireInitialization, JsonRpcConnectionOptions? jsonRpcOptions}) AcpV2ApplicationOptions
Returns a modified copy.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited