AcpV2ClientConnection class final

Client connection and agent-calling context.

Implemented types

Properties

agent AcpV2ClientContext
Context for agent-handled calls and sessions.
final
closed Future<void>
Completes when closed.
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
lifecycle AcpV2ConnectionLifecycle
Application lifecycle.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close([Object? reason]) → void
Closes idempotently.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
startConnectHandlers() → void
Starts deferred connect handlers exactly once.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited