AcpV2ClientRequestContext<P> class final

Client request handler context.

Inheritance

Constructors

AcpV2ClientRequestContext({required P params, required JsonRpcId requestId, required CancellationToken cancellationToken, required AcpV2ClientContext agent})
Creates handler context.
const

Properties

agent AcpV2ClientContext
Agent-calling context.
final
cancellationToken CancellationToken
Cooperative cancellation.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
params → P
Decoded params.
finalinherited
requestId JsonRpcId
JSON-RPC request id.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited