AcpV2CollectedText class final

Result of v2 text collection.

Constructors

AcpV2CollectedText({required String text, required String thoughts, required AcpV2PromptCompletion completion})
Creates collected text.
const

Properties

completion AcpV2PromptCompletion
Idle completion.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String
Materialized agent-message text.
final
thoughts String
Materialized thought text when requested.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited