AcpV2Connection class abstract interface

Shared behavior for a draft-v2 connection.

Implementers

Properties

closed Future<void>
Completes when closed.
no setter
hashCode int
The hash code for this object.
no setterinherited
lifecycle AcpV2ConnectionLifecycle
Application lifecycle.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close([Object? reason]) → void
Closes idempotently.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
startConnectHandlers() → void
Starts deferred connect handlers exactly once.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited