AcpV2ConnectionLifecycle class final

Coordinates v2 initialization and connection state.

Properties

cancellationToken CancellationToken
Cancels on connection close.
no setter
closed Future<void>
Completes when transport processing stops.
no setter
hashCode int
The hash code for this object.
no setterinherited
isReady bool
Whether normal methods may be used.
no setter
peerAuthMethods List<AuthMethod>
Authentication methods advertised by the initialized v2 agent.
no setter
peerCapabilities AcpV2PeerCapabilities
Capabilities advertised by the peer.
no setter
peerImplementation AcpJsonObject?
Peer implementation info.
no setter
ready Future<void>
Completes after initialization.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state AcpV2ConnectionState
Current state.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited