AcpV2ConnectionState enum
Current draft-v2 application lifecycle state.
Values
- initializing → const AcpV2ConnectionState
-
Waiting for
initialize. - ready → const AcpV2ConnectionState
-
Initialization succeeded.
- closed → const AcpV2ConnectionState
-
The transport closed.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
AcpV2ConnectionState> - A constant List of the values in this enum, in order of their declaration.