AcpV2MessageKind enum

Kind of message stored in a v2 snapshot.

Inheritance
Available extensions

Values

user → const AcpV2MessageKind

User message.

agent → const AcpV2MessageKind

Agent-visible response.

thought → const AcpV2MessageKind

Agent thought/reasoning message.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<AcpV2MessageKind>
A constant List of the values in this enum, in order of their declaration.