AcpV2SessionUpdateEvent class final

One sequenced session update.

Inheritance

Constructors

AcpV2SessionUpdateEvent({required int sequence, required UpdateSessionNotification notification, required AcpV2SessionSnapshot snapshot})
Creates an update event.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
notification UpdateSessionNotification
Full wire notification.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sequence int
Monotonic local observation sequence.
final
snapshot AcpV2SessionSnapshot
State after applying this update.
final
update SessionUpdate
Typed update.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited