AcpV2TerminalState class final

Materialized terminal state.

Constructors

AcpV2TerminalState({required TerminalId terminalId, required List<int> output, String? command, AbsolutePath? cwd, TerminalExitStatus? exitStatus})
Creates terminal state.
const

Properties

command String?
Current command.
final
cwd AbsolutePath?
Current working directory.
final
exitStatus TerminalExitStatus?
Current exit status.
final
hashCode int
The hash code for this object.
no setterinherited
output List<int>
Current output bytes.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
terminalId TerminalId
Agent-owned terminal ID.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited