Annotations class final

Optional annotations for the client. The client can use annotations to inform how objects are used or displayed

Implemented types
Annotations
  • @JsonSerializable.new(createFactory: false, createToJson: false)

Constructors

Annotations({List<Role>? audience, AcpDateTimeString? lastModified, num? priority, AcpJsonObject? meta})
Creates a Annotations value.
Annotations.fromJson(Map<String, Object?> json)
Decodes a JSON object, discarding recoverable issues.
factory

Properties

audience List<Role>?
Intended recipients for this content, such as the user or assistant.
final
hashCode int
The hash code for this object.
no setterinherited
lastModified AcpDateTimeString?
Timestamp indicating when the underlying resource was last modified.
final
meta AcpJsonObject?
The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
final
priority num?
Relative importance of this content when clients choose what to surface.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toAcpJson() AcpJsonObject
Converts this protocol value to its immutable JSON representation.
override
toJson() Map<String, Object?>
Encodes this value to its wire object.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

decode(Object? json) → AcpDecoded<Annotations>
Decodes this model and reports recoverable issues.