lastModified property
Timestamp indicating when the underlying resource was last modified.
Must be an RFC 3339 formatted string (e.g., "2025-01-12T15:00:58Z").
Implementation
final AcpDateTimeString? lastModified;
Timestamp indicating when the underlying resource was last modified.
Must be an RFC 3339 formatted string (e.g., "2025-01-12T15:00:58Z").
final AcpDateTimeString? lastModified;