AuthMethodAgent class final

Agent handles authentication itself through auth/login.

The type discriminator value is agent.

Implemented types
Annotations
  • @JsonSerializable.new(createFactory: false, createToJson: false)

Constructors

AuthMethodAgent({required AuthMethodId methodId, required String name, String? description, AcpJsonObject? meta})
Creates a AuthMethodAgent value.
AuthMethodAgent.fromJson(Map<String, Object?> json)
Decodes a JSON object, discarding recoverable issues.
factory

Properties

description String?
Optional description providing more details about this authentication method.
final
hashCode int
The hash code for this object.
no setterinherited
meta AcpJsonObject?
The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
final
methodId AuthMethodId
Unique identifier for this authentication method.
final
name String
Human-readable name of the authentication method.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toAcpJson() AcpJsonObject
Converts this protocol value to its immutable JSON representation.
override
toJson() Map<String, Object?>
Encodes this value to its wire object.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

decode(Object? json) → AcpDecoded<AuthMethodAgent>
Decodes this model and reports recoverable issues.