AvailableCommand class final

Information about a command.

Implemented types
Annotations
  • @JsonSerializable.new(createFactory: false, createToJson: false)

Constructors

AvailableCommand({required String name, required String description, AvailableCommandInput? input, AcpJsonObject? meta})
Creates a AvailableCommand value.
AvailableCommand.fromJson(Map<String, Object?> json)
Decodes a JSON object, discarding recoverable issues.
factory

Properties

description String
Human-readable description of what the command does.
final
hashCode int
The hash code for this object.
no setterinherited
input AvailableCommandInput?
Input for the command if required
final
meta AcpJsonObject?
The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
final
name String
Command name (e.g., create_plan, research_codebase).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toAcpJson() AcpJsonObject
Converts this protocol value to its immutable JSON representation.
override
toJson() Map<String, Object?>
Encodes this value to its wire object.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

decode(Object? json) → AcpDecoded<AvailableCommand>
Decodes this model and reports recoverable issues.