BlobResourceContents class final

Binary resource contents.

Implemented types
Annotations
  • @JsonSerializable.new(createFactory: false, createToJson: false)

Constructors

BlobResourceContents({required String blob, required Uri uri, MediaType? mimeType, AcpJsonObject? meta})
Creates a BlobResourceContents value.
BlobResourceContents.fromJson(Map<String, Object?> json)
Decodes a JSON object, discarding recoverable issues.
factory

Properties

blob String
Base64-encoded bytes for a binary resource payload.
final
hashCode int
The hash code for this object.
no setterinherited
meta AcpJsonObject?
The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
final
mimeType MediaType?
MIME type describing the encoded media payload.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
uri Uri
URI associated with this resource or media payload.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toAcpJson() AcpJsonObject
Converts this protocol value to its immutable JSON representation.
override
toJson() Map<String, Object?>
Encodes this value to its wire object.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

decode(Object? json) → AcpDecoded<BlobResourceContents>
Decodes this model and reports recoverable issues.