defaultValue property
Default value.
Optional. Omitted and null are equivalent and mean no default value is provided.
Implementation
final bool? defaultValue;
Default value.
Optional. Omitted and null are equivalent and mean no default value is provided.
final bool? defaultValue;