title property
Optional title for the property.
Optional. Omitted and null are equivalent and mean no title is provided.
Implementation
final String? title;
Optional title for the property.
Optional. Omitted and null are equivalent and mean no title is provided.
final String? title;