ClientRequest class final

A JSON-RPC request object.

Implemented types
Annotations
  • @JsonSerializable.new(createFactory: false, createToJson: false)

Constructors

ClientRequest({required RequestId id, required String method, AcpJsonValue? params})
Creates a ClientRequest value.
ClientRequest.fromJson(Map<String, Object?> json)
Decodes a JSON object, discarding recoverable issues.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
id RequestId
The request id used to correlate the matching response.
final
method String
The method name to invoke.
final
params AcpJsonValue?
Method-specific request parameters.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toAcpJson() AcpJsonObject
Converts this protocol value to its immutable JSON representation.
override
toJson() Map<String, Object?>
Encodes this value to its wire object.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

decode(Object? json) → AcpDecoded<ClientRequest>
Decodes this model and reports recoverable issues.