CloseSessionRequest class final

Request parameters for closing an active session.

The agent must cancel any ongoing work related to the session (treat it as if session/cancel was called) and then free up any resources associated with the session.

Implemented types
Annotations
  • @JsonSerializable.new(checked: true, explicitToJson: true, includeIfNull: false)

Constructors

CloseSessionRequest({required SessionId sessionId, AcpJsonObject? meta})
Creates a CloseSessionRequest value.
CloseSessionRequest.fromJson(Map<String, Object?> json)
Decodes a schema-validated JSON object.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
meta AcpJsonObject?
The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionId SessionId
The ID of the session to close.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toAcpJson() AcpJsonObject
Converts this protocol value to its immutable JSON representation.
override
toJson() Map<String, Object?>
Encodes this value to its wire object.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited