configOptions property
The full set of configuration options and their current values.
Implementation
final List<SessionConfigOption> configOptions;
The full set of configuration options and their current values.
final List<SessionConfigOption> configOptions;