ContentChunk class final

A streamed item of message content.

Implemented types
Annotations
  • @JsonSerializable.new(checked: true, explicitToJson: true, includeIfNull: false)

Constructors

ContentChunk({required MessageId messageId, required ContentBlock content, AcpJsonObject? meta})
Creates a ContentChunk value.
ContentChunk.fromJson(Map<String, Object?> json)
Decodes a schema-validated JSON object.
factory

Properties

content ContentBlock
A single item of content
final
hashCode int
The hash code for this object.
no setterinherited
messageId MessageId
A unique identifier for the message this chunk belongs to.
final
meta AcpJsonObject?
The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys. This field is chunk-scoped.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toAcpJson() AcpJsonObject
Converts this protocol value to its immutable JSON representation.
override
toJson() Map<String, Object?>
Encodes this value to its wire object.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited