changes property
Structured file changes described by this diff.
Clients can use this field without parsing patch text to determine affected paths.
Implementation
final List<DiffChange> changes;
Structured file changes described by this diff.
Clients can use this field without parsing patch text to determine affected paths.
final List<DiffChange> changes;