DiffChangeAdd class final

A file was added.

Inheritance

Constructors

DiffChangeAdd(DiffPathChange value, {DiffFileType? fileType, MediaType? mimeType, AcpJsonObject? meta})
Creates this known tagged-union variant.

Properties

discriminator String
The exact discriminator string.
no setteroverride
fileType DiffFileType?
File content kind.
final
hashCode int
The hash code for this object.
no setterinherited
meta AcpJsonObject?
The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
final
mimeType MediaType?
MIME type of the file contents.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value DiffPathChange
The typed variant payload.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toAcpJson() AcpJsonObject
Converts this protocol value to its immutable JSON representation.
override
toJson() Map<String, Object?>
Encodes the tagged union.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited