requestedSchema property
A JSON Schema describing the form fields to present to the user.
Implementation
final ElicitationSchema requestedSchema;
A JSON Schema describing the form fields to present to the user.
final ElicitationSchema requestedSchema;