ElicitationSessionScope class final

Session-scoped elicitation, optionally tied to a specific tool call.

When tool_call_id is set, the elicitation is tied to a specific tool call. This is useful when an agent receives an elicitation from an MCP server during a tool call and needs to redirect it to the user.

Implemented types
Annotations
  • @JsonSerializable.new(createFactory: false, createToJson: false)

Constructors

ElicitationSessionScope({required SessionId sessionId, ToolCallId? toolCallId})
Creates a ElicitationSessionScope value.
ElicitationSessionScope.fromJson(Map<String, Object?> json)
Decodes a JSON object, discarding recoverable issues.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionId SessionId
The session this elicitation is tied to.
final
toolCallId ToolCallId?
Optional tool call within the session.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toAcpJson() AcpJsonObject
Converts this protocol value to its immutable JSON representation.
override
toJson() Map<String, Object?>
Encodes this value to its wire object.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

decode(Object? json) → AcpDecoded<ElicitationSessionScope>
Decodes this model and reports recoverable issues.