toolCallId property

ToolCallId? toolCallId
final

Optional tool call within the session.

Optional. Omitted and null are equivalent and mean the elicitation is scoped to the session without a specific tool call.

Implementation

final ToolCallId? toolCallId;