annotations property
Optional annotations that help clients decide how to display or route this content.
Implementation
final Annotations? annotations;
Optional annotations that help clients decide how to display or route this content.
final Annotations? annotations;