code property
A number indicating the error type that occurred. This must be an integer as defined in the JSON-RPC specification.
Implementation
final ErrorCode code;
A number indicating the error type that occurred. This must be an integer as defined in the JSON-RPC specification.
final ErrorCode code;