message property
A string providing a short description of the error. The message should be limited to a concise single sentence.
Implementation
final String message;
A string providing a short description of the error. The message should be limited to a concise single sentence.
final String message;