ExtNotification class final
Allows the Agent to send an arbitrary notification that is not part of the ACP spec. Extension notifications provide a way to send one-way messages for custom functionality while maintaining protocol compatibility.
See protocol docs: Extensibility
- Implemented types
Constructors
- ExtNotification(AcpJsonValue value)
- Creates a raw-preserving schema union value.
- ExtNotification.fromJson(Object? json)
-
Decodes a union payload.
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → AcpJsonValue
-
The immutable union payload.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toAcpJson(
) → AcpJsonValue -
Converts this protocol value to its immutable JSON representation.
override
-
toJson(
) → Object? - Encodes the union payload.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited