Icon class final

An optionally-sized icon that can be displayed in a user interface.

Implemented types
Annotations
  • @JsonSerializable.new(createFactory: false, createToJson: false)

Constructors

Icon({required Uri src, MediaType? mimeType, List<String>? sizes, IconTheme? theme})
Creates a Icon value.
Icon.fromJson(Map<String, Object?> json)
Decodes a JSON object, discarding recoverable issues.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
mimeType MediaType?
Optional MIME type override if the source MIME type is missing or generic.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sizes List<String>?
Optional array of strings that specify sizes at which the icon can be used. Each string should be in WxH format (e.g., "48x48", "96x96") or "any" for scalable formats like SVG.
final
src Uri
A standard URI pointing to an icon resource.
final
theme IconTheme?
Optional theme this icon is designed for.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toAcpJson() AcpJsonObject
Converts this protocol value to its immutable JSON representation.
override
toJson() Map<String, Object?>
Encodes this value to its wire object.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

decode(Object? json) → AcpDecoded<Icon>
Decodes this model and reports recoverable issues.