IdleStateUpdate class final
The agent is ready to process a new prompt.
- Implemented types
- Annotations
-
- @JsonSerializable.new(createFactory: false, createToJson: false)
Constructors
-
IdleStateUpdate({AcpPatch<
StopReason> stopReason = const AcpPatch<StopReason>.unchanged(), AcpJsonObject? meta}) - Creates a IdleStateUpdate value.
-
IdleStateUpdate.fromJson(Map<
String, Object?> json) -
Decodes a JSON object, discarding recoverable issues.
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- meta → AcpJsonObject?
-
The _meta property is reserved by ACP to allow clients and agents to attach additional
metadata to their interactions. Implementations MUST NOT make assumptions about values at
these keys.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
stopReason
→ AcpPatch<
StopReason> -
Indicates why foreground work stopped.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toAcpJson(
) → AcpJsonObject -
Converts this protocol value to its immutable JSON representation.
override
-
toJson(
) → Map< String, Object?> - Encodes this value to its wire object.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
decode(
Object? json) → AcpDecoded< IdleStateUpdate> - Decodes this model and reports recoverable issues.