ImageContentCodec class final
Codec for ImageContent.
- Implemented types
Constructors
- ImageContentCodec()
-
Creates the codec.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
decode(
Object? value) → ImageContent -
Decodes a JSON-compatible wire value.
override
-
encode(
ImageContent value) → Object -
Encodes a value to JSON-compatible Dart objects.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited