Implementation class final

Metadata about the implementation of the client or agent. Describes the name and version of an ACP implementation, with an optional title for UI representation.

Implemented types
Annotations
  • @JsonSerializable.new(createFactory: false, createToJson: false)

Constructors

Implementation({required String name, required String version, String? title, AcpJsonObject? meta})
Creates a Implementation value.
Implementation.fromJson(Map<String, Object?> json)
Decodes a JSON object, discarding recoverable issues.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
meta AcpJsonObject?
The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
final
name String
Intended for programmatic or logical use, but can be used as a display name fallback if title isn’t present.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String?
Intended for UI and end-user contexts — optimized to be human-readable and easily understood.
final
version String
Version of the implementation. Can be displayed to the user or used for debugging or metrics purposes. (e.g. "1.0.0").
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toAcpJson() AcpJsonObject
Converts this protocol value to its immutable JSON representation.
override
toJson() Map<String, Object?>
Encodes this value to its wire object.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

decode(Object? json) → AcpDecoded<Implementation>
Decodes this model and reports recoverable issues.