name property
Intended for programmatic or logical use, but can be used as a display name fallback if title isn’t present.
Implementation
final String name;
Intended for programmatic or logical use, but can be used as a display name fallback if title isn’t present.
final String name;