title property
Intended for UI and end-user contexts — optimized to be human-readable and easily understood.
If not provided, the name should be used for display.
Implementation
final String? title;
Intended for UI and end-user contexts — optimized to be human-readable and easily understood.
If not provided, the name should be used for display.
final String? title;