InitializeResponse class final

Response to the initialize method.

Contains the negotiated protocol version and agent capabilities.

See protocol docs: Initialization

Implemented types
Annotations
  • @JsonSerializable.new(createFactory: false, createToJson: false)

Constructors

InitializeResponse({required ProtocolVersion protocolVersion, required Implementation info, required AgentCapabilities capabilities, List<AuthMethod>? authMethods, AcpJsonObject? meta})
Creates a InitializeResponse value.
InitializeResponse.fromJson(Map<String, Object?> json)
Decodes a JSON object, discarding recoverable issues.
factory

Properties

authMethods List<AuthMethod>?
Authentication methods supported by the agent.
final
capabilities AgentCapabilities
Capabilities supported by the agent.
final
hashCode int
The hash code for this object.
no setterinherited
info Implementation
Information about the implementation sending this initialize response.
final
meta AcpJsonObject?
The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
final
protocolVersion ProtocolVersion
The protocol version the client specified if supported by the agent, or the latest protocol version supported by the agent.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toAcpJson() AcpJsonObject
Converts this protocol value to its immutable JSON representation.
override
toJson() Map<String, Object?>
Encodes this value to its wire object.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

decode(Object? json) → AcpDecoded<InitializeResponse>
Decodes this model and reports recoverable issues.