authMethods property

List<AuthMethod>? authMethods
final

Authentication methods supported by the agent.

Optional. Omitted or empty means the agent does not advertise the authentication method surface. Supplying one or more valid methods means the agent MUST support both auth/login and auth/logout.

Implementation

final List<AuthMethod>? authMethods;