protocolVersion property

ProtocolVersion protocolVersion
final

The protocol version the client specified if supported by the agent, or the latest protocol version supported by the agent.

The client should disconnect, if it doesn't support this version.

Implementation

final ProtocolVersion protocolVersion;