IntegerPropertySchema class final

Schema for integer properties in an elicitation form.

Implemented types
Annotations
  • @JsonSerializable.new(createFactory: false, createToJson: false)

Constructors

IntegerPropertySchema({String? title, String? description, AcpInt64? minimum, AcpInt64? maximum, AcpInt64? defaultValue, AcpJsonObject? meta})
Creates a IntegerPropertySchema value.
IntegerPropertySchema.fromJson(Map<String, Object?> json)
Decodes a JSON object, discarding recoverable issues.
factory

Properties

defaultValue AcpInt64?
Default value.
final
description String?
Human-readable description.
final
hashCode int
The hash code for this object.
no setterinherited
maximum AcpInt64?
Maximum value (inclusive).
final
meta AcpJsonObject?
The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
final
minimum AcpInt64?
Minimum value (inclusive).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String?
Optional title for the property.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toAcpJson() AcpJsonObject
Converts this protocol value to its immutable JSON representation.
override
toJson() Map<String, Object?>
Encodes this value to its wire object.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

decode(Object? json) → AcpDecoded<IntegerPropertySchema>
Decodes this model and reports recoverable issues.