maximum property
Maximum value (inclusive).
Optional. Omitted and null are equivalent and mean there is no inclusive upper bound.
Implementation
final AcpInt64? maximum;
Maximum value (inclusive).
Optional. Omitted and null are equivalent and mean there is no inclusive upper bound.
final AcpInt64? maximum;