ListSessionsRequest class final

Request parameters for listing existing sessions.

Implemented types
Annotations
  • @JsonSerializable.new(createFactory: false, createToJson: false)

Constructors

ListSessionsRequest({AbsolutePath? cwd, SessionListCursor? cursor, AcpJsonObject? meta})
Creates a ListSessionsRequest value.
ListSessionsRequest.fromJson(Map<String, Object?> json)
Decodes a JSON object, discarding recoverable issues.
factory

Properties

cursor SessionListCursor?
Opaque cursor token from a previous response's nextCursor field for cursor-based pagination
final
cwd AbsolutePath?
Filter sessions by working directory. Must be an absolute path.
final
hashCode int
The hash code for this object.
no setterinherited
meta AcpJsonObject?
The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toAcpJson() AcpJsonObject
Converts this protocol value to its immutable JSON representation.
override
toJson() Map<String, Object?>
Encodes this value to its wire object.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

decode(Object? json) → AcpDecoded<ListSessionsRequest>
Decodes this model and reports recoverable issues.