McpServerCustom class final

An unknown future or _-prefixed McpServer variant.

Inheritance

Constructors

McpServerCustom({required String discriminator, required AcpJsonObject payload})
Creates a raw-preserving custom variant.

Properties

discriminator String
The exact discriminator string.
final
hashCode int
The hash code for this object.
no setterinherited
payload AcpJsonObject
Opaque extension fields.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toAcpJson() AcpJsonObject
Converts this protocol value to its immutable JSON representation.
override
toJson() Map<String, Object?>
Encodes the tagged union.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited