McpServerHttpVariant class final
HTTP transport configuration
Only available when the Agent capabilities include session.mcp.http.
Constructors
- McpServerHttpVariant(McpServerHttp value)
-
Creates this known tagged-union variant.
const
Properties
- discriminator → String
-
The exact discriminator string.
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → McpServerHttp
-
The typed variant payload.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toAcpJson(
) → AcpJsonObject -
Converts this protocol value to its immutable JSON representation.
override
-
toJson(
) → Map< String, Object?> -
Encodes the tagged union.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited