MultiSelectItems class sealed
Items for a multi-select (array) property schema.
- Implemented types
- Implementers
Constructors
- MultiSelectItems.fromJson(Object? json)
-
Decodes one concrete union member.
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toAcpJson(
) → AcpJsonValue -
Converts this protocol value to its immutable JSON representation.
override
-
toJson(
) → Object? - Encodes the concrete union member.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited