MultiSelectItemsOther class final
Custom or future typed multi-select items.
- Inheritance
-
- Object
- MultiSelectItems
- MultiSelectItemsOther
Constructors
- MultiSelectItemsOther(AcpJsonObject value)
- Creates this concrete union member.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → AcpJsonObject
-
The typed union value.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toAcpJson(
) → AcpJsonValue -
Converts this protocol value to its immutable JSON representation.
inherited
-
toJson(
) → Object? -
Encodes the concrete union member.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited