MultiSelectPropertySchema class final
Schema for multi-select (array) properties in an elicitation form.
- Implemented types
- Annotations
-
- @JsonSerializable.new(createFactory: false, createToJson: false)
Constructors
-
MultiSelectPropertySchema({required MultiSelectItems items, String? title, String? description, AcpUint64? minItems, AcpUint64? maxItems, List<
String> ? defaultValue, AcpJsonObject? meta}) - Creates a MultiSelectPropertySchema value.
-
MultiSelectPropertySchema.fromJson(Map<
String, Object?> json) -
Decodes a JSON object, discarding recoverable issues.
factory
Properties
-
defaultValue
→ List<
String> ? -
Default selected values.
final
- description → String?
-
Human-readable description.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- items → MultiSelectItems
-
The items definition describing allowed values.
final
- maxItems → AcpUint64?
-
Maximum number of items to select.
final
- meta → AcpJsonObject?
-
The _meta property is reserved by ACP to allow clients and agents to attach additional
metadata to their interactions. Implementations MUST NOT make assumptions about values at
these keys.
final
- minItems → AcpUint64?
-
Minimum number of items to select.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- title → String?
-
Optional title for the property.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toAcpJson(
) → AcpJsonObject -
Converts this protocol value to its immutable JSON representation.
override
-
toJson(
) → Map< String, Object?> - Encodes this value to its wire object.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
decode(
Object? json) → AcpDecoded< MultiSelectPropertySchema> - Decodes this model and reports recoverable issues.