PlanEntry class final

A single entry in the execution plan.

Represents a task or goal that the assistant intends to accomplish as part of fulfilling the user's request. See protocol docs: Plan Entries

Implemented types
Annotations
  • @JsonSerializable.new(checked: true, explicitToJson: true, includeIfNull: false)

Constructors

PlanEntry({required String content, required PlanEntryPriority priority, required PlanEntryStatus status, AcpJsonObject? meta})
Creates a PlanEntry value.
PlanEntry.fromJson(Map<String, Object?> json)
Decodes a schema-validated JSON object.
factory

Properties

content String
Human-readable description of what this task aims to accomplish.
final
hashCode int
The hash code for this object.
no setterinherited
meta AcpJsonObject?
The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
final
priority PlanEntryPriority
The relative importance of this task. Used to indicate which tasks are most critical to the overall goal.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status PlanEntryStatus
Current execution status of this task.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toAcpJson() AcpJsonObject
Converts this protocol value to its immutable JSON representation.
override
toJson() Map<String, Object?>
Encodes this value to its wire object.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited