PlanEntryPriority class final
Priority levels for plan entries.
Used to indicate the relative importance or urgency of different tasks in the execution plan. See protocol docs: Plan Entries
- Implemented types
Constructors
- PlanEntryPriority(String value)
-
Validates and creates a PlanEntryPriority value.
factory
- PlanEntryPriority.fromJson(Object? json)
-
Decodes a wire string.
factory
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toAcpJson(
) → AcpJsonString -
Converts this protocol value to its immutable JSON representation.
override
-
toJson(
) → String - Encodes the wire string.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- high → const PlanEntryPriority
-
The
highschema value. - low → const PlanEntryPriority
-
The
lowschema value. - medium → const PlanEntryPriority
-
The
mediumschema value.