PromptCapabilities class final

Prompt capabilities supported by the agent in session/prompt requests.

Baseline agent functionality requires support for ContentBlock::Text and ContentBlock::ResourceLink in prompt requests.

Other variants must be explicitly opted in to. Capabilities for different types of content in prompt requests.

Implemented types
Annotations
  • @JsonSerializable.new(createFactory: false, createToJson: false)

Constructors

PromptCapabilities({PromptImageCapabilities? image, PromptAudioCapabilities? audio, PromptEmbeddedContextCapabilities? embeddedContext, AcpJsonObject? meta})
Creates a PromptCapabilities value.
PromptCapabilities.fromJson(Map<String, Object?> json)
Decodes a JSON object, discarding recoverable issues.
factory

Properties

audio PromptAudioCapabilities?
Agent supports ContentBlock::Audio.
final
embeddedContext PromptEmbeddedContextCapabilities?
Agent supports embedded context in session/prompt requests.
final
hashCode int
The hash code for this object.
no setterinherited
image PromptImageCapabilities?
Agent supports ContentBlock::Image.
final
meta AcpJsonObject?
The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toAcpJson() AcpJsonObject
Converts this protocol value to its immutable JSON representation.
override
toJson() Map<String, Object?>
Encodes this value to its wire object.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

decode(Object? json) → AcpDecoded<PromptCapabilities>
Decodes this model and reports recoverable issues.