embeddedContext property

PromptEmbeddedContextCapabilities? embeddedContext
final

Agent supports embedded context in session/prompt requests.

When enabled, the Client is allowed to include ContentBlock::Resource in prompt requests for pieces of context that are referenced in the message.

Optional. Omitted or null both mean the agent does not advertise support. Supplying {} means the agent supports embedded context in prompts.

Implementation

final PromptEmbeddedContextCapabilities? embeddedContext;