image property
Agent supports ContentBlock::Image.
Optional. Omitted or null both mean the agent does not advertise support.
Supplying {} means the agent supports image content in prompts.
Implementation
final PromptImageCapabilities? image;
Agent supports ContentBlock::Image.
Optional. Omitted or null both mean the agent does not advertise support.
Supplying {} means the agent supports image content in prompts.
final PromptImageCapabilities? image;