ProtocolVersion class final

Protocol version identifier.

This version is only bumped for breaking changes. Non-breaking changes should be introduced via capabilities.

Implemented types

Constructors

ProtocolVersion(int value)
Validates and creates a ProtocolVersion value.
factory
ProtocolVersion.fromJson(Object? json)
Decodes a wire number.
factory

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
The exact wire number.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toAcpJson() AcpJsonNumber
Converts this protocol value to its immutable JSON representation.
override
toJson() int
Encodes the wire number.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override