ResourceLink class final

A resource that the server is capable of reading, included in a prompt or tool call result.

Implemented types
Annotations
  • @JsonSerializable.new(createFactory: false, createToJson: false)

Constructors

ResourceLink({required String name, required Uri uri, String? title, String? description, List<Icon>? icons, MediaType? mimeType, AcpInt64? size, Annotations? annotations, AcpJsonObject? meta})
Creates a ResourceLink value.
ResourceLink.fromJson(Map<String, Object?> json)
Decodes a JSON object, discarding recoverable issues.
factory

Properties

annotations Annotations?
Optional annotations that help clients decide how to display or route this content.
final
description String?
Optional human-readable details shown with this protocol object.
final
hashCode int
The hash code for this object.
no setterinherited
icons List<Icon>?
Optional set of sized icons that the client can display in a user interface.
final
meta AcpJsonObject?
The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
final
mimeType MediaType?
MIME type describing the encoded media payload.
final
name String
Human-readable name shown for this protocol object.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size AcpInt64?
Optional size of the linked resource in bytes, if known.
final
title String?
Optional display title for end-user UI.
final
uri Uri
URI associated with this resource or media payload.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toAcpJson() AcpJsonObject
Converts this protocol value to its immutable JSON representation.
override
toJson() Map<String, Object?>
Encodes this value to its wire object.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

decode(Object? json) → AcpDecoded<ResourceLink>
Decodes this model and reports recoverable issues.