ResumeSessionRequest class final

Request parameters for resuming an existing session.

Resumes an existing session and optionally replays prior conversation history according to replayFrom.

Implemented types
Annotations
  • @JsonSerializable.new(createFactory: false, createToJson: false)

Constructors

ResumeSessionRequest({required SessionId sessionId, required AbsolutePath cwd, List<AbsolutePath>? additionalDirectories, List<McpServer>? mcpServers, ReplayFrom? replayFrom, AcpJsonObject? meta})
Creates a ResumeSessionRequest value.
ResumeSessionRequest.fromJson(Map<String, Object?> json)
Decodes a JSON object, discarding recoverable issues.
factory

Properties

additionalDirectories List<AbsolutePath>?
Additional workspace roots to activate for this session. Each path must be absolute.
final
cwd AbsolutePath
The working directory for this session. Must be an absolute path.
final
hashCode int
The hash code for this object.
no setterinherited
mcpServers List<McpServer>?
List of MCP servers to connect to for this session.
final
meta AcpJsonObject?
The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
final
replayFrom ReplayFrom?
Inclusive cursor describing where conversation replay should begin.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionId SessionId
The ID of the session to resume.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toAcpJson() AcpJsonObject
Converts this protocol value to its immutable JSON representation.
override
toJson() Map<String, Object?>
Encodes this value to its wire object.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

decode(Object? json) → AcpDecoded<ResumeSessionRequest>
Decodes this model and reports recoverable issues.