Role class final

The sender or recipient of messages and data in a conversation.

Implemented types

Constructors

Role(String value)
Validates and creates a Role value.
factory
Role.fromJson(Object? json)
Decodes a wire string.
factory

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
The exact wire string.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toAcpJson() AcpJsonString
Converts this protocol value to its immutable JSON representation.
override
toJson() String
Encodes the wire string.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

assistant → const Role
The assistant schema value.
user → const Role
The user schema value.