SessionAdditionalDirectoriesCapabilities class final

Capabilities for additional session directories support.

Supplying {} means the agent supports the additionalDirectories field on supported session lifecycle requests. Agents that also support session/list may return SessionInfo.additionalDirectories to report the complete ordered additional-root list associated with a listed session.

Implemented types
Annotations
  • @JsonSerializable.new(checked: true, explicitToJson: true, includeIfNull: false)

Constructors

SessionAdditionalDirectoriesCapabilities({AcpJsonObject? meta})
Creates a SessionAdditionalDirectoriesCapabilities value.
SessionAdditionalDirectoriesCapabilities.fromJson(Map<String, Object?> json)
Decodes a schema-validated JSON object.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
meta AcpJsonObject?
The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toAcpJson() AcpJsonObject
Converts this protocol value to its immutable JSON representation.
override
toJson() Map<String, Object?>
Encodes this value to its wire object.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited