SessionCapabilities class final

Session capabilities supported by the agent.

Supplying {} means the agent supports the baseline session methods: session/new, session/list, session/resume, session/close, session/prompt, session/cancel, and session/update.

Agents that support sessions MAY support additional session methods, prompt content types, and MCP transports by specifying additional

Implemented types
Annotations
  • @JsonSerializable.new(createFactory: false, createToJson: false)

Constructors

SessionCapabilities({PromptCapabilities? prompt, McpCapabilities? mcp, SessionDeleteCapabilities? delete, SessionAdditionalDirectoriesCapabilities? additionalDirectories, AcpJsonObject? meta})
Creates a SessionCapabilities value.
SessionCapabilities.fromJson(Map<String, Object?> json)
Decodes a JSON object, discarding recoverable issues.
factory

Properties

additionalDirectories SessionAdditionalDirectoriesCapabilities?
Whether the agent supports additionalDirectories on supported session lifecycle requests.
final
delete SessionDeleteCapabilities?
Whether the agent supports session/delete.
final
hashCode int
The hash code for this object.
no setterinherited
mcp McpCapabilities?
MCP capabilities supported by the agent for session lifecycle requests.
final
meta AcpJsonObject?
The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
final
prompt PromptCapabilities?
Prompt capabilities supported by the agent in session/prompt requests.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toAcpJson() AcpJsonObject
Converts this protocol value to its immutable JSON representation.
override
toJson() Map<String, Object?>
Encodes this value to its wire object.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

decode(Object? json) → AcpDecoded<SessionCapabilities>
Decodes this model and reports recoverable issues.