SessionConfigOptionBoolean class final

Boolean on/off toggle.

Inheritance

Constructors

SessionConfigOptionBoolean(SessionConfigBoolean value, {required SessionConfigId configId, required String name, String? description, SessionConfigOptionCategory? category, AcpJsonObject? meta})
Creates this known tagged-union variant.

Properties

category SessionConfigOptionCategory?
Optional semantic category for this option (UX only).
final
configId SessionConfigId
Unique identifier for the configuration option.
final
description String?
Optional description for the Client to display to the user.
final
discriminator String
The exact discriminator string.
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
meta AcpJsonObject?
The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
final
name String
Human-readable label for the option.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value SessionConfigBoolean
The typed variant payload.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toAcpJson() AcpJsonObject
Converts this protocol value to its immutable JSON representation.
override
toJson() Map<String, Object?>
Encodes the tagged union.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited