SessionId class final

A unique identifier for a conversation session between a client and agent.

Sessions maintain their own context, conversation history, and state, allowing multiple independent interactions with the same agent.

See protocol docs: Session ID

Implemented types

Constructors

SessionId(String value)
Validates and creates a SessionId value.
factory
SessionId.fromJson(Object? json)
Decodes a wire string.
factory

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
The exact wire string.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toAcpJson() AcpJsonString
Converts this protocol value to its immutable JSON representation.
override
toJson() String
Encodes the wire string.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override