SessionInfo class final

Information about a session returned by session/list

Implemented types
Annotations
  • @JsonSerializable.new(createFactory: false, createToJson: false)

Constructors

SessionInfo({required SessionId sessionId, required AbsolutePath cwd, List<AbsolutePath>? additionalDirectories, String? title, AcpDateTimeString? updatedAt, AcpJsonObject? meta})
Creates a SessionInfo value.
SessionInfo.fromJson(Map<String, Object?> json)
Decodes a JSON object, discarding recoverable issues.
factory

Properties

additionalDirectories List<AbsolutePath>?
Additional workspace roots reported for this session. Each path must be absolute.
final
cwd AbsolutePath
The working directory for this session. Must be an absolute path.
final
hashCode int
The hash code for this object.
no setterinherited
meta AcpJsonObject?
The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionId SessionId
Unique identifier for the session
final
title String?
Human-readable title for the session
final
updatedAt AcpDateTimeString?
RFC 3339 timestamp of last activity.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toAcpJson() AcpJsonObject
Converts this protocol value to its immutable JSON representation.
override
toJson() Map<String, Object?>
Encodes this value to its wire object.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

decode(Object? json) → AcpDecoded<SessionInfo>
Decodes this model and reports recoverable issues.