SessionUpdate class sealed
Different types of updates that can be sent while a session exists.
These updates report messages, progress, and other session activity.
See protocol docs: Agent Reports Output
- Implemented types
- Implementers
- SessionUpdateAgentMessage
- SessionUpdateAgentMessageChunk
- SessionUpdateAgentThought
- SessionUpdateAgentThoughtChunk
- SessionUpdateAvailableCommandsUpdate
- SessionUpdateConfigOptionUpdate
- SessionUpdateCustom
- SessionUpdatePlanUpdate
- SessionUpdateSessionInfoUpdate
- SessionUpdateStateUpdate
- SessionUpdateTerminalOutputChunk
- SessionUpdateTerminalUpdate
- SessionUpdateToolCallContentChunk
- SessionUpdateToolCallUpdate
- SessionUpdateUsageUpdate
- SessionUpdateUserMessage
- SessionUpdateUserMessageChunk
Constructors
- SessionUpdate.fromJson(Object? json)
-
Decodes the tagged union.
factory
Properties
- discriminator → String
-
The exact discriminator string.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toAcpJson(
) → AcpJsonValue -
Converts this protocol value to its immutable JSON representation.
inherited
-
toJson(
) → Map< String, Object?> - Encodes the tagged union.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited