StopReason class final

Reasons why an agent stops active session work.

See protocol docs: Stop Reasons

Implemented types

Constructors

StopReason(String value)
Validates and creates a StopReason value.
factory
StopReason.fromJson(Object? json)
Decodes a wire string.
factory

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
The exact wire string.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toAcpJson() AcpJsonString
Converts this protocol value to its immutable JSON representation.
override
toJson() String
Encodes the wire string.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

cancelled → const StopReason
The cancelled schema value.
endTurn → const StopReason
The end_turn schema value.
maxTokens → const StopReason
The max_tokens schema value.
maxTurnRequests → const StopReason
The max_turn_requests schema value.
refusal → const StopReason
The refusal schema value.