maxLength property
Maximum string length.
Optional. Omitted and null are equivalent and mean there is no maximum length constraint.
Implementation
final int? maxLength;
Maximum string length.
Optional. Omitted and null are equivalent and mean there is no maximum length constraint.
final int? maxLength;