pattern property
Pattern the string must match.
Optional. Omitted and null are equivalent and mean there is no pattern constraint.
Implementation
final String? pattern;
Pattern the string must match.
Optional. Omitted and null are equivalent and mean there is no pattern constraint.
final String? pattern;