Terminal class final

A display-only reference to an agent-owned terminal.

Terminal state and output are delivered separately through TerminalUpdate and TerminalOutputChunk.

Implemented types
Annotations
  • @JsonSerializable.new(checked: true, explicitToJson: true, includeIfNull: false)

Constructors

Terminal({required TerminalId terminalId, AcpJsonObject? meta})
Creates a Terminal value.
Terminal.fromJson(Map<String, Object?> json)
Decodes a schema-validated JSON object.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
meta AcpJsonObject?
The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys. This metadata is scoped to the content reference. Omitted and null are equivalent and mean no item metadata was provided.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
terminalId TerminalId
The ID of the terminal to display.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toAcpJson() AcpJsonObject
Converts this protocol value to its immutable JSON representation.
override
toJson() Map<String, Object?>
Encodes this value to its wire object.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited