meta property

AcpJsonObject? meta
final

The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys. This metadata is scoped to the exit information. Omitted and null are equivalent and mean no exit metadata was provided.

See protocol docs: Extensibility

Implementation

final AcpJsonObject? meta;