meta property

  1. @JsonKey.new(name: '_meta')
  2. @AcpMetaConverter()
AcpJsonObject? meta
final

The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys. This field is chunk-scoped. Omitted and null are equivalent and mean no chunk metadata was provided.

See protocol docs: Extensibility

Implementation

@JsonKey(name: '_meta')
@AcpMetaConverter()
final AcpJsonObject? meta;