ToolCallContent class sealed

Content produced by a tool call.

Tool calls can produce different types of content including standard content blocks (text, images), file diffs, or display-only terminals.

See protocol docs: Content

Implemented types
Implementers

Constructors

ToolCallContent.fromJson(Object? json)
Decodes the tagged union.
factory

Properties

discriminator String
The exact discriminator string.
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toAcpJson() AcpJsonValue
Converts this protocol value to its immutable JSON representation.
inherited
toJson() Map<String, Object?>
Encodes the tagged union.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited