ToolCallContentChunk class final

A streamed item of tool-call content.

Tool-call content chunks append one ToolCallContent item to the current content for the matching ToolCallId. Agents can use ToolCallUpdate::content when they need to replace the whole content collection instead.

Implemented types
Annotations
  • @JsonSerializable.new(checked: true, explicitToJson: true, includeIfNull: false)

Constructors

ToolCallContentChunk({required ToolCallId toolCallId, required ToolCallContent content, AcpJsonObject? meta})
Creates a ToolCallContentChunk value.
ToolCallContentChunk.fromJson(Map<String, Object?> json)
Decodes a schema-validated JSON object.
factory

Properties

content ToolCallContent
A single item of content produced by the tool call.
final
hashCode int
The hash code for this object.
no setterinherited
meta AcpJsonObject?
The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys. This field is chunk-scoped.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
toolCallId ToolCallId
The ID of the tool call this content belongs to.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toAcpJson() AcpJsonObject
Converts this protocol value to its immutable JSON representation.
override
toJson() Map<String, Object?>
Encodes this value to its wire object.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited