ToolCallStatus class final

Execution status of a tool call.

Tool calls progress through different statuses during their lifecycle.

See protocol docs: Status

Implemented types

Constructors

ToolCallStatus(String value)
Validates and creates a ToolCallStatus value.
factory
ToolCallStatus.fromJson(Object? json)
Decodes a wire string.
factory

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
The exact wire string.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toAcpJson() AcpJsonString
Converts this protocol value to its immutable JSON representation.
override
toJson() String
Encodes the wire string.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

cancelled → const ToolCallStatus
The cancelled schema value.
completed → const ToolCallStatus
The completed schema value.
failed → const ToolCallStatus
The failed schema value.
inProgress → const ToolCallStatus
The in_progress schema value.
pending → const ToolCallStatus
The pending schema value.