ToolCallStatusCodec class final

Codec for ToolCallStatus.

Implemented types

Constructors

ToolCallStatusCodec()
Creates the codec.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

decode(Object? value) ToolCallStatus
Decodes a JSON-compatible wire value.
override
encode(ToolCallStatus value) String
Encodes a value to JSON-compatible Dart objects.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited