UpdateSessionNotification class final

Notification containing a session update from the agent.

Agents can send session updates at any point while the session exists.

See protocol docs: Agent Reports Output

Implemented types
Annotations
  • @JsonSerializable.new(checked: true, explicitToJson: true, includeIfNull: false)

Constructors

UpdateSessionNotification({required SessionId sessionId, required SessionUpdate update, AcpJsonObject? meta})
Creates a UpdateSessionNotification value.
UpdateSessionNotification.fromJson(Map<String, Object?> json)
Decodes a schema-validated JSON object.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
meta AcpJsonObject?
The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionId SessionId
The ID of the session this update pertains to.
final
update SessionUpdate
The actual update content.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toAcpJson() AcpJsonObject
Converts this protocol value to its immutable JSON representation.
override
toJson() Map<String, Object?>
Encodes this value to its wire object.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited