elicitationCreateMethod top-level constant

Request from the agent to elicit structured user input.

The agent sends this to the client to request information from the user, either via a form or by directing them to a URL. Elicitations are tied to a session (optionally a tool call) or a request.

Implementation

const AcpMethodDescriptor<CreateElicitationRequest, CreateElicitationResponse>
elicitationCreateMethod =
    AcpMethodDescriptor<CreateElicitationRequest, CreateElicitationResponse>(
      name: 'elicitation/create',
      dartName: 'elicitationCreate',
      protocol: AcpProtocolGeneration.v2,
      stability: AcpMethodStability.draft,
      direction: AcpMethodDirection.agentToClient,
      kind: AcpMethodKind.request,
      paramsDefinition: 'CreateElicitationRequest',
      paramsCodec: createElicitationRequestCodec,
      resultCodec: createElicitationResponseCodec,
      resultDefinition: 'CreateElicitationResponse',
      capabilityPath: 'capabilities.elicitation',
      documentation:
          'Request from the agent to elicit structured user input.\n\nThe agent sends this to the client to request information from the user,\neither via a form or by directing them to a URL.\nElicitations are tied to a session (optionally a tool call) or a request.',
    );