sessionCloseMethod top-level constant

Request parameters for closing an active session.

The agent must cancel any ongoing work related to the session (treat it as if session/cancel was called) and then free up any resources associated with the session.

Implementation

const AcpMethodDescriptor<CloseSessionRequest, CloseSessionResponse>
sessionCloseMethod = AcpMethodDescriptor<CloseSessionRequest, CloseSessionResponse>(
  name: 'session/close',
  dartName: 'sessionClose',
  protocol: AcpProtocolGeneration.v2,
  stability: AcpMethodStability.draft,
  direction: AcpMethodDirection.clientToAgent,
  kind: AcpMethodKind.request,
  paramsDefinition: 'CloseSessionRequest',
  paramsCodec: closeSessionRequestCodec,
  resultCodec: closeSessionResponseCodec,
  resultDefinition: 'CloseSessionResponse',
  capabilityPath: 'capabilities.session',
  documentation:
      'Request parameters for closing an active session.\n\nThe agent **must** cancel any ongoing work related to the session (treat it\nas if `session/cancel` was called) and then free up any resources associated\nwith the session.',
);