AcpWebSocketBinaryFrame class final

One unsupported binary frame.

Inheritance

Constructors

AcpWebSocketBinaryFrame(List<int> bytes)
Creates a binary frame.

Properties

bytes List<int>
Binary payload.
final
hashCode int
The hash code for this object.
no setterinherited
length int
Payload byte length used by transport limits.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited