AcpWebSocketConnectRequest class final

Immutable request to open a WebSocket.

Constructors

AcpWebSocketConnectRequest({required Uri uri, List<String> protocols = const <String>[], AcpHttpHeaders headers = const AcpHttpHeaders()})
Creates a connection request.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
headers AcpHttpHeaders
Native handshake headers. Browsers reject nonempty custom headers.
final
protocols List<String>
Requested subprotocols.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
uri Uri
WebSocket URI.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited