AcpHttpClientLimits class final
Bounded resource settings for AcpHttpClientTransport.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- maximumBodyBytes → int
-
Maximum non-streaming response body bytes.
final
- maximumJsonNestingDepth → int
-
Maximum structural object/array nesting in inbound JSON.
final
- maximumPendingSessionRequests → int
-
Maximum session-routed requests awaiting responses.
final
- maximumSseEventBytes → int
-
Maximum combined bytes in one SSE event.
final
- maximumSseLineBytes → int
-
Maximum bytes in one SSE line.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
validate(
) → void - Validates every limit even when Dart assertions are disabled.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited