AcpHttpResponse class final
One platform-neutral streaming HTTP response.
Constructors
-
AcpHttpResponse({required int statusCode, required AcpHttpHeaders headers, required Stream<
List< body, String reasonPhrase = ''})int> > -
Creates a response.
const
Properties
-
body
→ Stream<
List< int> > -
Response body chunks. Cancellation must stop platform reads.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- headers → AcpHttpHeaders
-
Immutable response headers, including repeated
Set-Cookievalues.final - isSuccessful → bool
-
Whether the response is a 2xx success.
no setter
- reasonPhrase → String
-
Safe status description when supplied by the platform.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- statusCode → int
-
HTTP status code.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited