AcpSseLimits class final
Limits applied to one server-sent event stream.
Constructors
- AcpSseLimits({int maximumLineBytes = 16 * 1024 * 1024, int maximumEventBytes = 16 * 1024 * 1024, int maximumJsonNestingDepth = 128})
-
Creates validated limits.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- maximumEventBytes → int
-
Maximum combined UTF-8 bytes in one event's
datafields.final - maximumJsonNestingDepth → int
-
Maximum structural object/array nesting in one event payload.
final
- maximumLineBytes → int
-
Maximum bytes in one SSE line.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
validate(
) → void - Validates every limit even when Dart assertions are disabled.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited