AcpProtocolRouter class final
Routes an incoming transport to the requested or latest configured agent.
Constructors
- AcpProtocolRouter({AcpAgentApp? v1, AcpV2AgentApp? v2})
- Creates a router with optional protocol implementations.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
connect(
AcpDuplexStream< Object?> stream, {AcpProtocolRouterConnectOptions options = const AcpProtocolRouterConnectOptions()}) → AcpRoutedAgentConnection - Routes one transport after consuming and validating its first frame.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
withV1(
AcpAgentApp agent) → AcpProtocolRouter - Configures the stable-v1 agent.
-
withV2(
AcpV2AgentApp agent) → AcpProtocolRouter - Configures the draft-v2 agent.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited