AcpRoutedAgentConnection class final
Lifecycle handle returned before version selection completes.
Properties
-
closed
→ Future<
void> -
Completes when routing or the selected application connection ends.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selectedProtocolVersion → int?
-
Selected protocol version, once the initialize frame is routed.
no setter
Methods
-
close(
[Object? reason]) → void - Closes the selected connection and destination writer.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
startConnectHandlers(
) → void - Starts selected app connect handlers exactly once.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited