AcpOutboundOverflow class final
Details about a subscriber queue that dropped its oldest value.
Constructors
- AcpOutboundOverflow({required int capacity, required int droppedValues})
-
Creates an overflow diagnostic.
const
Properties
- capacity → int
-
The configured queue capacity.
final
- droppedValues → int
-
Values dropped during the current overflow episode.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited