AcpOutboundSubscription<T> class
final
One subscription to an AcpOutboundHub.
Only the first subscription receives replay. Later subscriptions receive an empty list and observe live values only.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
live
→ Stream<
T> -
The bounded stream of live values for this subscriber.
final
-
replay
→ List<
T> -
Values buffered before the first subscription was created.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited