AcpWebSocketServer class final
Adapter-neutral experimental ACP WebSocket server.
Constructors
- AcpWebSocketServer({required AcpServerConnectionFactory createConnection, AcpServerConnectionRegistry? registry, AcpRemoteServerLimits limits = const AcpRemoteServerLimits(), JsonRpcCodec codec = const JsonRpcCodec(), AcpWebSocketUpgradePolicy? upgradePolicy})
-
Creates a WebSocket server around
createConnection.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- socketCount → int
-
Number of accepted sockets that have not closed.
no setter
Methods
-
close(
) → Future< void> - Closes sockets with code 1001 and releases every connection.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
prepare(
AcpWebSocketUpgradeContext context) → Future< AcpPreparedWebSocketUpgrade> - Runs policy and reserves one pending connection.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited