AcpWebSocketUpgradeContext class final
Context passed to a WebSocket origin/authentication preflight.
Constructors
- AcpWebSocketUpgradeContext({required Uri uri, AcpHttpHeaders headers = const AcpHttpHeaders()})
-
Creates an immutable upgrade context.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- headers → AcpHttpHeaders
-
Sanitized upgrade request headers.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- uri → Uri
-
Requested endpoint.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited