AcpV2AgentNotificationContext<P> class
final
Agent notification handler context.
Constructors
- AcpV2AgentNotificationContext({required P params, required CancellationToken cancellationToken, required AcpV2AgentContext client})
-
Creates handler context.
const
Properties
- cancellationToken → CancellationToken
-
Cancels on connection close.
final
- client → AcpV2AgentContext
-
Client-calling context.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- params → P
-
Decoded params.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited