AcpV2ClientContext class final
Client-side context used to call the agent.
- Inheritance
-
- Object
- AcpV2CallContext
- AcpV2ClientContext
- Available extensions
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- lifecycle → AcpV2ConnectionLifecycle
-
Lifecycle of the containing connection.
finalinherited
- options → AcpV2ApplicationOptions
-
App behavior options.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sessions ↔ AcpV2Sessions
-
Session creation and resume helpers.
latefinal
Methods
-
authLogin(
LoginAuthRequest params, {CancellationToken? cancellationToken}) → Future< LoginAuthResponse> -
Available on AcpV2ClientContext, provided by the AcpV2ClientMethods extension
Authenticates with one method advertised during initialization. -
authLogout(
LogoutAuthRequest params, {CancellationToken? cancellationToken}) → Future< LogoutAuthResponse> -
Available on AcpV2ClientContext, provided by the AcpV2ClientMethods extension
Terminates the current authenticated session. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notify<
P> (AcpMethodDescriptor< P, AcpNoResult> method, P params) → Future<void> -
Sends a typed notification.
inherited
-
request<
P, R> (AcpMethodDescriptor< P, R> method, P params, {CancellationToken? cancellationToken}) → Future<R> -
Sends a typed request.
inherited
-
sendBatch(
AcpV2Batch batch) → Future< List< Object?> > -
Sends one non-empty heterogeneous v2 batch frame.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited