AcpV2ClientNotificationContext<P> class
final
Client notification handler context.
Constructors
- AcpV2ClientNotificationContext({required P params, required CancellationToken cancellationToken, required AcpV2ClientContext agent})
-
Creates handler context.
const
Properties
- agent → AcpV2ClientContext
-
Agent-calling context.
final
- cancellationToken → CancellationToken
-
Cancels on connection close.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- params → P
-
Decoded params.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited