AcpV2MessageState class final
Materialized message content after replacement and chunk semantics.
Constructors
-
AcpV2MessageState({required MessageId messageId, required AcpV2MessageKind kind, required List<
ContentBlock> content}) -
Creates message state.
const
Properties
-
content
→ List<
ContentBlock> -
Current complete content.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- kind → AcpV2MessageKind
-
Message role/category.
final
- messageId → MessageId
-
Agent-owned message ID.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited