Curated generated method descriptors for the baseline draft-v2 API.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
authLogin
→ const AcpMethodDescriptor<
LoginAuthRequest, LoginAuthResponse> - Authentication login.
-
authLogout
→ const AcpMethodDescriptor<
LogoutAuthRequest, LogoutAuthResponse> - Authentication logout.
-
cancelRequest
→ const AcpMethodDescriptor<
CancelRequestNotification, AcpNoResult> - Protocol cancellation.
-
cancelSession
→ const AcpMethodDescriptor<
CancelSessionNotification, AcpNoResult> - Cancel session work.
-
closeSession
→ const AcpMethodDescriptor<
CloseSessionRequest, CloseSessionResponse> - Close a session.
-
completeElicitation
→ const AcpMethodDescriptor<
CompleteElicitationNotification, AcpNoResult> - Complete elicitation.
-
createElicitation
→ const AcpMethodDescriptor<
CreateElicitationRequest, CreateElicitationResponse> - Create elicitation.
-
deleteSession
→ const AcpMethodDescriptor<
DeleteSessionRequest, DeleteSessionResponse> - Delete a session.
-
initialize
→ const AcpMethodDescriptor<
InitializeRequest, InitializeResponse> - Initialize.
-
listSessions
→ const AcpMethodDescriptor<
ListSessionsRequest, ListSessionsResponse> - List sessions.
-
newSession
→ const AcpMethodDescriptor<
NewSessionRequest, NewSessionResponse> - Create a session.
-
prompt
→ const AcpMethodDescriptor<
PromptRequest, PromptResponse> - Submit a prompt.
-
requestPermission
→ const AcpMethodDescriptor<
RequestPermissionRequest, RequestPermissionResponse> - Request permission.
-
resumeSession
→ const AcpMethodDescriptor<
ResumeSessionRequest, ResumeSessionResponse> - Resume a session.
-
setSessionConfigOption
→ const AcpMethodDescriptor<
SetSessionConfigOptionRequest, SetSessionConfigOptionResponse> - Set a configuration option.
-
updateSession
→ const AcpMethodDescriptor<
UpdateSessionNotification, AcpNoResult> - Send a session update.