AgentResponse class final
A JSON-RPC response object.
- Implemented types
Constructors
- AgentResponse(AcpJsonValue value)
- Creates a raw-preserving schema union value.
- AgentResponse.fromJson(Object? json)
-
Decodes a union payload.
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → AcpJsonValue
-
The immutable union payload.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toAcpJson(
) → AcpJsonValue -
Converts this protocol value to its immutable JSON representation.
override
-
toJson(
) → Object? - Encodes the union payload.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited