CommandPermissionSubject class final
Permission request details for a command.
- Implemented types
- Annotations
-
- @JsonSerializable.new(createFactory: false, createToJson: false)
Constructors
- CommandPermissionSubject({required String command, required AbsolutePath cwd, ToolCallId? toolCallId, TerminalId? terminalId, AcpJsonObject? meta})
- Creates a CommandPermissionSubject value.
-
CommandPermissionSubject.fromJson(Map<
String, Object?> json) -
Decodes a JSON object, discarding recoverable issues.
factory
Properties
- command → String
-
The command that would be run if permission is granted.
final
- cwd → AbsolutePath
-
The absolute working directory for the command.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- meta → AcpJsonObject?
-
The _meta property is reserved by ACP to allow clients and agents to attach additional
metadata to their interactions. Implementations MUST NOT make assumptions about values at
these keys. Omitted and
nullare equivalent and mean no subject metadata was provided.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- terminalId → TerminalId?
-
The associated terminal, when already known. Omitted and
nullare equivalent.final - toolCallId → ToolCallId?
-
The associated tool call, when known. Omitted and
nullare equivalent.final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toAcpJson(
) → AcpJsonObject -
Converts this protocol value to its immutable JSON representation.
override
-
toJson(
) → Map< String, Object?> - Encodes this value to its wire object.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
decode(
Object? json) → AcpDecoded< CommandPermissionSubject> - Decodes this model and reports recoverable issues.