CreateElicitationRequest class sealed
Request from the agent to elicit structured user input.
The agent sends this to the client to request information from the user, either via a form or by directing them to a URL. Elicitations are tied to a session (optionally a tool call) or a request.
- Implemented types
- Implementers
Constructors
- CreateElicitationRequest.fromJson(Object? json)
-
Decodes the tagged union.
factory
Properties
- discriminator → String
-
The exact discriminator string.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toAcpJson(
) → AcpJsonValue -
Converts this protocol value to its immutable JSON representation.
inherited
-
toJson(
) → Map< String, Object?> - Encodes the tagged union.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited