CreateElicitationRequestForm class final
Form-based elicitation where the client renders a form from the provided schema.
- Inheritance
-
- Object
- CreateElicitationRequest
- CreateElicitationRequestForm
Constructors
- CreateElicitationRequestForm(ElicitationFormMode value, {required String message, AcpJsonObject? meta})
- Creates this known tagged-union variant.
Properties
- discriminator → String
-
The exact discriminator string.
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
A human-readable message describing what input is needed.
final
- meta → AcpJsonObject?
-
The _meta property is reserved by ACP to allow clients and agents to attach additional
metadata to their interactions. Implementations MUST NOT make assumptions about values at
these keys.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → ElicitationFormMode
-
The typed variant payload.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toAcpJson(
) → AcpJsonObject -
Converts this protocol value to its immutable JSON representation.
override
-
toJson(
) → Map< String, Object?> -
Encodes the tagged union.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited