patch property
Renderable patch text for some or all of the structured changes.
Agents SHOULD provide patch text whenever feasible. Omitted or null
means no renderable patch text was provided.
Implementation
final DiffPatch? patch;
Renderable patch text for some or all of the structured changes.
Agents SHOULD provide patch text whenever feasible. Omitted or null
means no renderable patch text was provided.
final DiffPatch? patch;