DiffPatch class final
Renderable patch text and its format.
- Implemented types
- Annotations
-
- @JsonSerializable.new(checked: true, explicitToJson: true, includeIfNull: false)
Constructors
- DiffPatch({required DiffPatchFormat format, required String text})
- Creates a DiffPatch value.
-
DiffPatch.fromJson(Map<
String, Object?> json) -
Decodes a schema-validated JSON object.
factory
Properties
- format → DiffPatchFormat
-
Patch format. The only ACP-defined value is
git_patch.final - hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- text → String
-
Patch text in the format named by
format.final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toAcpJson(
) → AcpJsonObject -
Converts this protocol value to its immutable JSON representation.
override
-
toJson(
) → Map< String, Object?> - Encodes this value to its wire object.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited