ElicitationFormMode class final
Form-based elicitation mode where the client renders a form from the provided schema.
- Implemented types
Constructors
- ElicitationFormMode({required ElicitationSchema requestedSchema, required ElicitationFormModeVariant variant})
- Creates a ElicitationFormMode value.
-
ElicitationFormMode.fromJson(Map<
String, Object?> json) -
Decodes a JSON object, discarding recoverable issues.
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- requestedSchema → ElicitationSchema
-
A JSON Schema describing the form fields to present to the user.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- variant → ElicitationFormModeVariant
-
The concrete schema composition branch.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toAcpJson(
) → AcpJsonObject -
Converts this protocol value to its immutable JSON representation.
override
-
toJson(
) → Map< String, Object?> - Encodes this value to its wire object.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
decode(
Object? json) → AcpDecoded< ElicitationFormMode> - Decodes this composed model with resilient fields.