ElicitationFormModeRequest class final
Tied to a specific JSON-RPC request outside of a session (e.g., during auth/configuration phases before any session is started).
- Inheritance
-
- Object
- ElicitationFormModeVariant
- ElicitationFormModeRequest
Constructors
- ElicitationFormModeRequest(ElicitationRequestScope value)
-
Creates this typed composition branch.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → ElicitationRequestScope
-
The typed branch payload.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
Encodes the branch fields into their flattened object.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited