toolCallId property
Optional tool call within the session.
Optional. Omitted and null are equivalent and mean the elicitation is scoped to the
session without a specific tool call.
Implementation
final ToolCallId? toolCallId;
Optional tool call within the session.
Optional. Omitted and null are equivalent and mean the elicitation is scoped to the
session without a specific tool call.
final ToolCallId? toolCallId;