InitializeRequest class final
Request parameters for the initialize method.
Sent by the client to establish connection and negotiate capabilities.
See protocol docs: Initialization
- Implemented types
- Annotations
-
- @JsonSerializable.new(createFactory: false, createToJson: false)
Constructors
- InitializeRequest({required ProtocolVersion protocolVersion, required Implementation info, required ClientCapabilities capabilities, AcpJsonObject? meta})
- Creates a InitializeRequest value.
-
InitializeRequest.fromJson(Map<
String, Object?> json) -
Decodes a JSON object, discarding recoverable issues.
factory
Properties
- capabilities → ClientCapabilities
-
Capabilities supported by the client.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- info → Implementation
-
Information about the implementation sending this initialize request.
final
- meta → AcpJsonObject?
-
The _meta property is reserved by ACP to allow clients and agents to attach additional
metadata to their interactions. Implementations MUST NOT make assumptions about values at
these keys.
final
- protocolVersion → ProtocolVersion
-
The latest protocol version supported by the client.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toAcpJson(
) → AcpJsonObject -
Converts this protocol value to its immutable JSON representation.
override
-
toJson(
) → Map< String, Object?> - Encodes this value to its wire object.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
decode(
Object? json) → AcpDecoded< InitializeRequest> - Decodes this model and reports recoverable issues.