ListSessionsResponse class final
Response from listing sessions.
- Implemented types
- Annotations
-
- @JsonSerializable.new(createFactory: false, createToJson: false)
Constructors
-
ListSessionsResponse({required List<
SessionInfo> sessions, SessionListCursor? nextCursor, AcpJsonObject? meta}) - Creates a ListSessionsResponse value.
-
ListSessionsResponse.fromJson(Map<
String, Object?> json) -
Decodes a JSON object, discarding recoverable issues.
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- meta → AcpJsonObject?
-
The _meta property is reserved by ACP to allow clients and agents to attach additional
metadata to their interactions. Implementations MUST NOT make assumptions about values at
these keys.
final
- nextCursor → SessionListCursor?
-
Opaque cursor token. If present, pass this in the next request's cursor parameter
to fetch the next page. If absent, there are no more results.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
sessions
→ List<
SessionInfo> -
Array of session information objects.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toAcpJson(
) → AcpJsonObject -
Converts this protocol value to its immutable JSON representation.
override
-
toJson(
) → Map< String, Object?> - Encodes this value to its wire object.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
decode(
Object? json) → AcpDecoded< ListSessionsResponse> - Decodes this model and reports recoverable issues.