LoginAuthRequest class final
Request parameters for the auth/login method.
Specifies which authentication method to use.
Agents MUST support this method when their initialize response advertised
at least one valid authentication method. Clients MUST NOT call this method
when authMethods was omitted or empty.
- Implemented types
- Annotations
-
- @JsonSerializable.new(checked: true, explicitToJson: true, includeIfNull: false)
Constructors
- LoginAuthRequest({required AuthMethodId methodId, AcpJsonObject? meta})
- Creates a LoginAuthRequest value.
-
LoginAuthRequest.fromJson(Map<
String, Object?> json) -
Decodes a schema-validated JSON object.
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- meta → AcpJsonObject?
-
The _meta property is reserved by ACP to allow clients and agents to attach additional
metadata to their interactions. Implementations MUST NOT make assumptions about values at
these keys.
final
- methodId → AuthMethodId
-
The ID of the authentication method to use.
Must be one of the methods advertised in the initialize response.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toAcpJson(
) → AcpJsonObject -
Converts this protocol value to its immutable JSON representation.
override
-
toJson(
) → Map< String, Object?> - Encodes this value to its wire object.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited