NumberPropertySchema class final
Schema for number (floating-point) properties in an elicitation form.
- Implemented types
- Annotations
-
- @JsonSerializable.new(createFactory: false, createToJson: false)
Constructors
- NumberPropertySchema({String? title, String? description, num? minimum, num? maximum, num? defaultValue, AcpJsonObject? meta})
- Creates a NumberPropertySchema value.
-
NumberPropertySchema.fromJson(Map<
String, Object?> json) -
Decodes a JSON object, discarding recoverable issues.
factory
Properties
- defaultValue → num?
-
Default value.
final
- description → String?
-
Human-readable description.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- maximum → num?
-
Maximum value (inclusive).
final
- meta → AcpJsonObject?
-
The _meta property is reserved by ACP to allow clients and agents to attach additional
metadata to their interactions. Implementations MUST NOT make assumptions about values at
these keys.
final
- minimum → num?
-
Minimum value (inclusive).
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- title → String?
-
Optional title for the property.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toAcpJson(
) → AcpJsonObject -
Converts this protocol value to its immutable JSON representation.
override
-
toJson(
) → Map< String, Object?> - Encodes this value to its wire object.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
decode(
Object? json) → AcpDecoded< NumberPropertySchema> - Decodes this model and reports recoverable issues.