SessionConfigBoolean class final
A boolean on/off toggle session configuration option payload.
- Implemented types
- Annotations
-
- @JsonSerializable.new(checked: true, explicitToJson: true, includeIfNull: false)
Constructors
- SessionConfigBoolean({required bool currentValue})
- Creates a SessionConfigBoolean value.
-
SessionConfigBoolean.fromJson(Map<
String, Object?> json) -
Decodes a schema-validated JSON object.
factory
Properties
- currentValue → bool
-
The current value of the boolean option.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toAcpJson(
) → AcpJsonObject -
Converts this protocol value to its immutable JSON representation.
override
-
toJson(
) → Map< String, Object?> - Encodes this value to its wire object.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited