SessionConfigSelect class final
A single-value selector (dropdown) session configuration option payload.
- Implemented types
- Annotations
-
- @JsonSerializable.new(checked: true, explicitToJson: true, includeIfNull: false)
Constructors
- SessionConfigSelect({required SessionConfigValueId currentValue, required SessionConfigSelectOptions options})
- Creates a SessionConfigSelect value.
-
SessionConfigSelect.fromJson(Map<
String, Object?> json) -
Decodes a schema-validated JSON object.
factory
Properties
- currentValue → SessionConfigValueId
-
The currently selected value.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- options → SessionConfigSelectOptions
-
The set of selectable options.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toAcpJson(
) → AcpJsonObject -
Converts this protocol value to its immutable JSON representation.
override
-
toJson(
) → Map< String, Object?> - Encodes this value to its wire object.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited