TerminalExitStatus class final
Exit information for an agent-owned terminal.
The presence of this object marks the terminal as exited, even when neither an exit code nor a signal is known.
- Implemented types
- Annotations
-
- @JsonSerializable.new(createFactory: false, createToJson: false)
Constructors
- TerminalExitStatus({int? exitCode, String? signal, AcpJsonObject? meta})
- Creates a TerminalExitStatus value.
-
TerminalExitStatus.fromJson(Map<
String, Object?> json) -
Decodes a JSON object, discarding recoverable issues.
factory
Properties
- exitCode → int?
-
Process exit code, when known. Omitted and
nullare equivalent.final - hashCode → int
-
The hash code for this object.
no setterinherited
- meta → AcpJsonObject?
-
The _meta property is reserved by ACP to allow clients and agents to attach additional
metadata to their interactions. Implementations MUST NOT make assumptions about values at
these keys. This metadata is scoped to the exit information. Omitted
and
nullare equivalent and mean no exit metadata was provided.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- signal → String?
-
Signal that terminated the process, when known.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toAcpJson(
) → AcpJsonObject -
Converts this protocol value to its immutable JSON representation.
override
-
toJson(
) → Map< String, Object?> - Encodes this value to its wire object.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
decode(
Object? json) → AcpDecoded< TerminalExitStatus> - Decodes this model and reports recoverable issues.