TerminalOutput class final
An authoritative replacement snapshot of terminal output bytes.
- Implemented types
- Annotations
-
- @JsonSerializable.new(checked: true, explicitToJson: true, includeIfNull: false)
Constructors
- TerminalOutput({required String data, AcpJsonObject? meta})
- Creates a TerminalOutput value.
-
TerminalOutput.fromJson(Map<
String, Object?> json) -
Decodes a schema-validated JSON object.
factory
Properties
- data → String
-
Base64-encoded replacement terminal output bytes.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- meta → AcpJsonObject?
-
The _meta property is reserved by ACP to allow clients and agents to attach additional
metadata to their interactions. Implementations MUST NOT make assumptions about values at
these keys. This metadata is scoped to the replacement snapshot. Omitted
and
nullare equivalent and mean no snapshot metadata was provided.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toAcpJson(
) → AcpJsonObject -
Converts this protocol value to its immutable JSON representation.
override
-
toJson(
) → Map< String, Object?> - Encodes this value to its wire object.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited