meta property
The _meta property is reserved by ACP to allow clients and agents to attach additional
metadata to their interactions. Implementations MUST NOT make assumptions about values at
these keys. This metadata is scoped to the replacement snapshot. Omitted
and null are equivalent and mean no snapshot metadata was provided.
See protocol docs: Extensibility
Implementation
@JsonKey(name: '_meta')
@AcpMetaConverter()
final AcpJsonObject? meta;