ToolCallStatus class final
Execution status of a tool call.
Tool calls progress through different statuses during their lifecycle.
See protocol docs: Status
- Implemented types
Constructors
- ToolCallStatus(String value)
-
Validates and creates a ToolCallStatus value.
factory
- ToolCallStatus.fromJson(Object? json)
-
Decodes a wire string.
factory
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toAcpJson(
) → AcpJsonString -
Converts this protocol value to its immutable JSON representation.
override
-
toJson(
) → String - Encodes the wire string.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- cancelled → const ToolCallStatus
-
The
cancelledschema value. - completed → const ToolCallStatus
-
The
completedschema value. - failed → const ToolCallStatus
-
The
failedschema value. - inProgress → const ToolCallStatus
-
The
in_progressschema value. - pending → const ToolCallStatus
-
The
pendingschema value.