UsageUpdate class final
Context window and cost update for a session.
- Implemented types
- Annotations
-
- @JsonSerializable.new(createFactory: false, createToJson: false)
Constructors
-
UsageUpdate({required AcpUint64 used, required AcpUint64 size, AcpPatch<
Cost> cost = const AcpPatch<Cost>.unchanged(), AcpJsonObject? meta}) - Creates a UsageUpdate value.
-
UsageUpdate.fromJson(Map<
String, Object?> json) -
Decodes a JSON object, discarding recoverable issues.
factory
Properties
-
cost
→ AcpPatch<
Cost> -
Cumulative session cost (optional).
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- meta → AcpJsonObject?
-
The _meta property is reserved by ACP to allow clients and agents to attach additional
metadata to their interactions. Implementations MUST NOT make assumptions about values at
these keys.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- size → AcpUint64
-
Total context window size in tokens.
final
- used → AcpUint64
-
Tokens currently in context.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toAcpJson(
) → AcpJsonObject -
Converts this protocol value to its immutable JSON representation.
override
-
toJson(
) → Map< String, Object?> - Encodes this value to its wire object.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
decode(
Object? json) → AcpDecoded< UsageUpdate> - Decodes this model and reports recoverable issues.