sessionDeleteMethod top-level constant
Request parameters for deleting an existing session from session/list.
Only available if the Agent supports the session.delete capability.
Implementation
const AcpMethodDescriptor<DeleteSessionRequest, DeleteSessionResponse>
sessionDeleteMethod =
AcpMethodDescriptor<DeleteSessionRequest, DeleteSessionResponse>(
name: 'session/delete',
dartName: 'sessionDelete',
protocol: AcpProtocolGeneration.v2,
stability: AcpMethodStability.draft,
direction: AcpMethodDirection.clientToAgent,
kind: AcpMethodKind.request,
paramsDefinition: 'DeleteSessionRequest',
paramsCodec: deleteSessionRequestCodec,
resultCodec: deleteSessionResponseCodec,
resultDefinition: 'DeleteSessionResponse',
capabilityPath: 'capabilities.session.delete',
documentation:
'Request parameters for deleting an existing session from `session/list`.\n\nOnly available if the Agent supports the `session.delete` capability.',
);