sessionUpdateMethod top-level constant
Notification containing a session update from the agent.
Agents can send session updates at any point while the session exists.
See protocol docs: Agent Reports Output
Implementation
const AcpMethodDescriptor<UpdateSessionNotification, AcpNoResult>
sessionUpdateMethod = AcpMethodDescriptor<UpdateSessionNotification, AcpNoResult>(
name: 'session/update',
dartName: 'sessionUpdate',
protocol: AcpProtocolGeneration.v2,
stability: AcpMethodStability.draft,
direction: AcpMethodDirection.agentToClient,
kind: AcpMethodKind.notification,
paramsDefinition: 'UpdateSessionNotification',
paramsCodec: updateSessionNotificationCodec,
resultCodec: acpNoResultCodec,
resultDefinition: null,
capabilityPath: null,
documentation:
'Notification containing a session update from the agent.\n\nAgents can send session updates at any point while the session exists.\n\nSee protocol docs: [Agent Reports Output](https://agentclientprotocol.com/protocol/v2/prompt-lifecycle#3-agent-reports-output)',
);