One connected WebSocket channel.
Properties
-
closed
→ Future<
void> -
Completes after the peer closes or the socket fails.
no setter
-
frames
→ Stream<
AcpWebSocketFrame> -
Incoming text and binary frames.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- responseHeaders → AcpHttpHeaders
-
Upgrade response headers when exposed by the platform.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
close(
{int? code, String? reason}) → Future< void> - Closes the socket.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
sendText(
String text) → Future< void> - Sends one text frame.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited